@@ -8,7 +8,7 @@ use Test2::Compare::Meta();
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000031';
+our $VERSION = '0.000033';
 
 use Test2::Util::HashBase qw/calls meta refcheck ending/;
 
@@ -67,9 +67,11 @@ sub add_item {
 
 sub add_call {
     my $self = shift;
-    my ($meth, $check, $name) = @_;
-    $name ||= ref $meth ? '\&CODE' : $meth;
-    push @{$self->{+CALLS}} => [$meth, $check, $name];
+    my ($meth, $check, $name, $context) = @_;
+    $name ||= ref $meth eq 'ARRAY' ? $meth->[0]
+        : ref $meth eq 'CODE' ? '\&CODE'
+        : $meth;
+    push @{$self->{+CALLS}} => [$meth, $check, $name, $context || 'scalar'];
 }
 
 sub deltas {
@@ -84,13 +86,26 @@ sub deltas {
     push @deltas => $meta->deltas(%params) if $meta;
 
     for my $call (@{$self->{+CALLS}}) {
-        my ($meth, $check, $name)= @$call;
+        my ($meth, $check, $name, $context)= @$call;
+        $context ||= 'scalar';
 
         $check = $convert->($check);
 
+        my @args;
+        if (ref($meth) eq 'ARRAY') {
+            ($meth,@args) = @{$meth};
+        }
+
         my $exists = ref($meth) || $got->can($meth);
         my $val;
-        my ($ok, $err) = try { $val = $exists ? $got->$meth : undef };
+        my ($ok, $err) = try {
+            $val = $exists
+                ? ( $context eq 'list' ? [ $got->$meth(@args) ] :
+                    $context eq 'hash' ? { $got->$meth(@args) } :
+                    $got->$meth(@args)
+                )
+                : undef;
+        };
 
         if (!$ok) {
             push @deltas => $self->delta_class->new(
@@ -187,10 +202,24 @@ just delegates.
 
 =item $obj->add_call($method, $check, $name)
 
+=item $obj->add_call($method, $check, $name, $context)
+
 Add a method call check. This will call the specified method on your object and
-verify the result. C<$method> may be a method name, or a coderef. In the case
-of a coderef it can be helpful to provide an alternate name. When no name is
-provided the name is either C<$method> or the string '\&CODE'.
+verify the result. C<$method> may be a method name, an array ref, or a coderef.
+
+If it's an arrayref, the first element must be the method name, and
+the rest are arguments that will be passed to it.
+
+In the case of a coderef it can be helpful to provide an alternate
+name. When no name is provided the name is either C<$method> or the
+string '\&CODE'.
+
+If C<$context> is C<'list'>, the method will be invoked in list
+context, and the result will be an arrayref.
+
+If C<$context> is C<'hash'>, the method will be invoked in list
+context, and the result will be a hashref (this will warn if the
+method returns an odd number of values).
 
 =back
 
